/*-
 * Copyright 2021 Hochschule für Technik Stuttgart
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package de.hft.stuttgart.citygml.viewer.datastructure;

import java.awt.Color;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

import de.hft.stuttgart.citygml.viewer.math.Vector3d;

public class Polygon {

	private Ring exteriorRing;
	private List<Ring> interiorRings;
	private Color color;
	
	public Polygon(Color color) {
		this.color = color;
	}
	
	public Color getColor() {
		return color;
	}
	
	public Ring getExteriorRing() {
		return exteriorRing;
	}

	public void setExteriorRing(Ring exteriorRing) {
		this.exteriorRing = exteriorRing;
	}

	public void addInteriorRing(Ring innerRing) {
		if (interiorRings == null) {
			interiorRings = new ArrayList<>();
		}
		interiorRings.add(innerRing);
	}

	public List<Ring> getInteriorRings() {
		if (interiorRings == null) {
			return Collections.emptyList();
		}
		return interiorRings;
	}

	public Vector3d calculateNormal() {
		return exteriorRing.calculateNormal();
	}

}
