/*-
 * Copyright 2021 Hochschule für Technik Stuttgart
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package de.hft.stuttgart.citygml.viewer.datastructure;

import java.awt.Color;
import java.util.ArrayList;
import java.util.List;

import de.hft.stuttgart.citygml.viewer.math.Vector3d;

public class TesselatedPolygon {
	

	private List<Triangle3d> triangles;
	private Vector3d normal;
	private Color color;
	
	public static TesselatedPolygon of(Polygon p) {
		TesselatedPolygon tessP = JoglTesselator.tesselatePolygon(p);
		tessP.normal = p.calculateNormal();
		tessP.color = p.getColor();
		return tessP;
	}

	public TesselatedPolygon(List<Triangle3d> triangles) {
		this.triangles = triangles;
	}

	public TesselatedPolygon(List<Vector3d> vertices, List<Integer> indices) {
		if (indices.size() % 3 != 0) {
			throw new IllegalArgumentException("Number of indices is not a multiple of 3");
		}
		triangles = new ArrayList<>();
		for (int i = 0; i < indices.size(); i = i + 3) {
			Vector3d v1 = vertices.get(indices.get(i + 0));
			Vector3d v2 = vertices.get(indices.get(i + 1));
			Vector3d v3 = vertices.get(indices.get(i + 2));
			triangles.add(new Triangle3d(v1, v2, v3));
		}
	}

	public List<Triangle3d> getTriangles() {
		return triangles;
	}
	
	public Vector3d getNormal() {
		return normal;
	}

	public Color getColor() {
		return color;
	}

}
