package de.hft.stuttgart.citygml.viewer.parser;

import java.awt.Color;
import java.io.FileReader;
import java.util.Properties;
import java.util.logging.Logger;

public class ColorHandler {
	
	private static final Logger logger = Logger.getLogger(ColorHandler.class.getName());

	private static Color groundColor = new Color(0.9411765f, 0.9019608f, 0.54901963f);
	private static Color roofColor = Color.RED;
	private static Color doorColor = Color.ORANGE;
	private static Color windowColor = new Color(0.0f, 0.5019608f, 0.5019608f);
	private static Color wallColor = Color.WHITE;
	private static Color bridgeColor = new Color(1.0f, 0.49803922f, 0.3137255f);
	private static Color landColor = new Color(0.64705884f, 0.16470589f, 0.16470589f);
	private static Color transportationColor = new Color(1.0f, 1.0f, 0.0f);
	private static Color vegetationColor = new Color(0.5647059f, 0.93333334f, 0.5647059f);
	private static Color waterColor = new Color(0.5294118f, 0.80784315f, 0.98039216f);
	
	static {
		try (FileReader reader = new FileReader("color.properties")) {
			Properties props = new Properties();
			props.load(reader);
			Color parsedGroundColor = parseColor(props.getProperty("groundColor"));
			if (parsedGroundColor != null) {
				groundColor = parsedGroundColor;
			}
			Color parsedRoofColor = parseColor(props.getProperty("roofColor"));
			if (parsedRoofColor != null) {
				roofColor = parsedRoofColor;
			}
			Color parsedDoorColor = parseColor(props.getProperty("doorColor"));
			if (parsedDoorColor != null) {
				doorColor = parsedDoorColor;
			}
			Color parsedWindowColor = parseColor(props.getProperty("windowColor"));
			if (parsedWindowColor != null) {
				windowColor = parsedWindowColor;
			}
			Color parsedWallColor = parseColor(props.getProperty("wallColor"));
			if (parsedWallColor != null) {
				wallColor = parsedWallColor;
			}
			Color parsedBridgeColor = parseColor(props.getProperty("bridgeColor"));
			if (parsedBridgeColor != null) {
				bridgeColor = parsedBridgeColor;
			}
			Color parsedLandColor = parseColor(props.getProperty("landColor"));
			if (parsedLandColor != null) {
				landColor = parsedLandColor;
			}
			Color parsedTransportationColor = parseColor(props.getProperty("transportationColor"));
			if (parsedTransportationColor != null) {
				transportationColor = parsedTransportationColor;
			}
			Color parsedVegetationColor = parseColor(props.getProperty("vegetationColor"));
			if (parsedVegetationColor != null) {
				vegetationColor = parsedVegetationColor;
			}
			Color parsedWaterColor = parseColor(props.getProperty("waterColor"));
			if (parsedWaterColor != null) {
				waterColor = parsedWaterColor;
			}
		}catch (Exception e) {
			logger.warning(() -> "Failed to read color properties file: " + e.getMessage());
		}
	}
	
	private ColorHandler() {
	}
	
	private static Color parseColor(String colorString) {
		if (colorString == null) {
			return null;
		}
		try {
			String[] split = colorString.split(" ");
			float r = Float.parseFloat(split[0]);
			float g = Float.parseFloat(split[1]);
			float b = Float.parseFloat(split[2]);
			return new Color(r, g, b);
		} catch (Exception e) {
			e.printStackTrace();
			return null;
		}
	}

	public static Color getGroundColor() {
		return groundColor;
	}

	public static Color getRoofColor() {
		return roofColor;
	}

	public static Color getDoorColor() {
		return doorColor;
	}

	public static Color getWindowColor() {
		return windowColor;
	}

	public static Color getWallColor() {
		return wallColor;
	}

	public static Color getBridgeColor() {
		return bridgeColor;
	}

	public static Color getLandColor() {
		return landColor;
	}

	public static Color getTransportationColor() {
		return transportationColor;
	}

	public static Color getVegetationColor() {
		return vegetationColor;
	}

	public static Color getWaterColor() {
		return waterColor;
	}

}
