package de.hft.stuttgart.citygml.viewer.parser;

import java.awt.Color;
import java.io.BufferedReader;
import java.io.IOException;
import java.nio.file.Files;
import java.nio.file.Path;
import java.util.HashMap;
import java.util.Map;
import java.util.function.Function;

import javax.swing.JOptionPane;

public class PolygonColorMapper {
	
	private static final String IGNORING_ALL_POLYGON_COLOR_MAPPINGS = "\nIgnoring all polygon color mappings";
	private static Function<String, Color> producer;
	private static Map<String, Color> colorMap;
	
	static {
		loadColorMap();
	}


	private static void loadColorMap() {
		Path colorMappingPath = Path.of("colorMappings.csv");
		if (!Files.exists(colorMappingPath)) {
			producer = s -> null;
			return;
		}
		try (BufferedReader reader = Files.newBufferedReader(colorMappingPath)) {
			colorMap = new HashMap<>();
			String line = null;
			while ((line = reader.readLine()) != null) {
				if (line.startsWith("#")) {
					// skip comments
					continue;
				}
				String[] mappingStrings = line.split(",");
				String polygonId = mappingStrings[0];
				int r = Integer.parseInt(mappingStrings[1]);
				if (r < 0 || r > 255) {
					JOptionPane.showMessageDialog(null, "Wrong red value " + r + " for polygon: " + polygonId + IGNORING_ALL_POLYGON_COLOR_MAPPINGS, "Warning", JOptionPane.WARNING_MESSAGE);
					colorMap = null;
					producer = s -> null;
					return;
				}
				int g = Integer.parseInt(mappingStrings[2]);
				if (g < 0 || g > 255) {
					JOptionPane.showMessageDialog(null, "Wrong green value " + g + " for polygon: " + polygonId + IGNORING_ALL_POLYGON_COLOR_MAPPINGS, "Warning", JOptionPane.WARNING_MESSAGE);
					colorMap = null;
					producer = s -> null;
					return;
				}
				int b = Integer.parseInt(mappingStrings[3]);
				if (b < 0 || b > 255) {
					JOptionPane.showMessageDialog(null, "Wrong green value " + b + " for polygon: " + polygonId + IGNORING_ALL_POLYGON_COLOR_MAPPINGS, "Warning", JOptionPane.WARNING_MESSAGE);
					colorMap = null;
					producer = s -> null;
					return;
				}
				Color color = new Color(r, g, b);
				colorMap.put(polygonId, color);
			}
			if (colorMap.isEmpty()) {
				producer = s -> null;
			} else {
				producer = s -> colorMap.get(s);
			}
		} catch (IOException e) {
			JOptionPane.showMessageDialog(null, "Could not read mapping csv file, ignoring: " + e.getMessage(), "Warning", JOptionPane.WARNING_MESSAGE);
		}
	}
	
	
	public static Color getColorForPolygon(String polygonId) {
		return producer.apply(polygonId);
	}
	
	private PolygonColorMapper() {
	}

}
